Description Usage Arguments Functions
Client functions to authenticate into my personal R server
1 2 3 4 5 6 7 |
url |
API call |
pwd |
Provide password explicitly if not stored internally or as environmental variable |
... |
Body arguments |
package |
internal |
fn |
internal |
tk_name |
internal |
POST_OCPU: POST request
GET_OCPU: GET request (typically comes after POST)
hpds_fn: tbd
get_token: DigitalOcean API
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.